**************************************
* This program creates Table 5
**************************************

* Preliminary setup -- check packages
capture log close
log using do_tables.log, text replace
net install outreg2, from(http://fmwww.bc.edu/RePEc/bocode/o)

* Set directory path -- to where DTA and DO files are.
cd "U:\_store_work\Perceived-Multipliers\Analysis\STATA\WP archive"

*****************************************
* Read in data
*****************************************

clear
clear matrix
set more off
set mem 500m
set more off
use dta.dta

*****************************************
* Set up baseline sample
*****************************************

gen sample=1 if (eu==1|wdicode=="CHE"|wdicode=="ISL"|wdicode=="NOR")

*****************************************
* Table 5. Europe:
* Government Revenue and Spending
*****************************************

preserve
* Settings
local title = "G vs T"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen z = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
bys ifscode: gen gz = ggx_gdp2010spring*(1+(ngap2010spring/100))  -  ggx_gdp2010spring[_n-2]*(1+(ngap2010spring[_n-2]/100))
bys ifscode: gen tz = z+gz
* Sample
keep if year==2011
keep if sample==1
* Regression
reg y gz tz, r
test _b[gz]+_b[tz]=0
local pvalue = r(p)
* Store results in outreg table
	outreg2 using T5.xls, ///
	addstat("p-value", `pvalue') ///
	ctitle("`title'") bdec(3) ///
	replace
restore

preserve
* Settings
local title = "G (primary) vs T"
* Variables
bys ifscode: gen y = 100*((1+ngdp_rpch2012fall/100)*(1+ngdp_rpch2012fall[_n-1]/100)-1)  -  100*((1+ngdp_rpch2010spring/100)*(1+ngdp_rpch2010spring[_n-1]/100)-1)
bys ifscode: gen z = ggsb_gdp2010spring-ggsb_gdp2010spring[_n-2]
bys ifscode: gen gz = ggx_gdp2010spring*(1+(ngap2010spring/100))  -  ggx_gdp2010spring[_n-2]*(1+(ngap2010spring[_n-2]/100))
bys ifscode: gen tz = z+gz
bys ifscode: replace gz = gz - (  ggei_gdp2010spring*(1+(ngap2010spring/100))  -  ggei_gdp2010spring[_n-2]*(1+(ngap2010spring[_n-2]/100))  )
* Sample
keep if year==2011
keep if sample==1
* Regression
reg y gz tz, r
test _b[gz]+_b[tz]=0
local pvalue = r(p)
* Store results in outreg table
	outreg2 using T5.xls, ///
	addstat("p-value", `pvalue') ///
	ctitle("`title'") bdec(3) ///
	append
restore

log close

